-------------------------------------------------------------------------------
--                G  O  B  A  L     V  A  R  I  A  B  L  E  S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
--                L  O  C  A  L     V  A  R  I  A  B  L  E  S
-------------------------------------------------------------------------------

local addonName, L = ...;

local currencyInfo =
{
  {id = 395}, -- Justice Points
  {id = 396}, -- Valor Points
  {id = 392}, -- Honor Points
  {id = 390}, -- Conquest Points
  {id = 697}, -- Elder Charm of Good Fortune
  {id = 752}, -- Mogu Rune of Fate
  {id = 398}, -- Draenei Archaeology Fragment
  {id = 384}, -- Dwarf Archaeology Fragment
  {id = 393}, -- Fossil Archaeology Fragment
  {id = 754}, -- Mantid Archaeology Fragment
  {id = 677}, -- Mogu Archaeology Fragment
  {id = 400}, -- Nerubian Archaeology Fragment
  {id = 394}, -- Night Elf Archaeology Fragment
  {id = 397}, -- Orc Archaeology Fragment
  {id = 676}, -- Pandaren Archaeology Fragment
  {id = 401}, -- Tol'vir Archaeology Fragment
  {id = 385}, -- Troll Archaeology Fragment
  {id = 399}  -- Vrykul Archaeology Fragment
};

local dropDownMenuInfo =
{
  {
    label   = L["Weekly"],
    value   = 0x01
  },
  {
    label   = L["Total"],
    value   = 0x02
  },
  {
    label   = L["WeeklyTotal"],
    value   = 0x03
  }
};

-------------------------------------------------------------------------------
--               G  L  O  B  A  L     F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

--
-- Function to check if any currency is at or near its limit
--
function NigglesCurrencyCheck()
  -- Local Variables
  local name;
  local string = "";
  local texture;
  local totalAmt;
  local totalMax;
  local weeklyAmt;
  local weeklyMax;

  -- Search for currencies at or near their maximum
  for _, current in ipairs(currencyInfo) do
    name, totalAmt, texture, weeklyAmt, weeklyMax, totalMax =
      GetCurrencyInfo(current.id);
    if ((name ~= nil) and (name ~= "")) then
      -- Adjust the maxima, if necessary
      if (weeklyMax > 10000) then
        weeklyMax = weeklyMax/100;
      end
      if (totalMax > 10000) then
        totalMax = totalMax/100;
      end

      -- Check if the currency is more than 90% of its weekly or total maximum
      if (((bit.band(NigglesDBC.settings.WarningCurrencyMask, 0x01) ~= 0) and
           (weeklyMax > 0) and
           (weeklyAmt > (weeklyMax*0.9))) or
          ((bit.band(NigglesDBC.settings.WarningCurrencyMask, 0x02) ~= 0) and
           (totalMax > 0) and
           (totalAmt > (totalMax*0.9)))) then
        -- Check if the player has already been warned
        if (current.warned ~= true) then
          -- NOTE: The '|r' is done after the '\n' to overcome a Blizzard bug
          string = string.."\124T"..texture..
            ":0:0:0:-8\124t "..GetCurrencyLink(current.id).."\n|r";
          current.warned = true;
        end
      else
        current.warned = false;
      end
    end
  end

  -- Check if there are any warnings to be displayed
  if (string ~= "") then
    -- Create the Niggles warning popup, if required
    if (NigglesWarningPopup == nil) then
      CreateFrame("Frame", "NigglesWarningPopup", UIParent,
        "NigglesWarningPopupTemplate");
    end

    -- Set the info to be displayed
    NigglesWarningPopup.text:SetText(L["CurrencyMax"]);
    NigglesWarningPopup.list:SetText(string);
    NigglesWarningPopup.list:Show();
    NigglesWarningPopup.item:Hide();

    -- Display the frame
    StaticPopupSpecial_Show(NigglesWarningPopup);
  end

  return;
end

--
-- Function to initialise a drop down menu for Niggles Options Warnings panel
--
function NigglesOptionsCurrencyMenuInit(dropDown)
  -- Local Variables
  local selectedValue = UIDropDownMenu_GetSelectedValue(dropDown);
  local info          = UIDropDownMenu_CreateInfo();

  -- Add each menu item in the supplied table
  for _, element in pairs(dropDownMenuInfo) do
    info.text      = L[element.label];
    info.func      = NigglesOptionsDropDownOnClick;
    info.arg1      = dropDown;
    info.value     = element.value;
    info.colorCode = element.color;
    if (info.value == selectedValue) then
      info.checked = 1;
    else
      info.checked = nil;
    end
    UIDropDownMenu_AddButton(info);
  end

  return;
end

--
-- Function to initialise a drop down menu for Niggles Options Warnings panel
--
function NigglesOptionsCurrencyMenuOnLoad(dropDown)
  -- Initialise some variables for the dropDown menu
  dropDown.type          = CONTROLTYPE_DROPDOWN;
  dropDown.SetValue      = NigglesOptionsDropDownSetValue;
  dropDown.nglSetting    = "WarningCurrencyMask";
  dropDown.nglMenuItems  = dropDownMenuInfo;
  dropDown.nglObjectType = "UIDropDownMenu";

  -- Initialise the dropDown menu
  UIDropDownMenu_Initialize(dropDown, NigglesOptionsCurrencyMenuInit);
  UIDropDownMenu_JustifyText(dropDown, "LEFT");
  UIDropDownMenu_SetWidth(dropDown, 110);

  return;
end
