-------------------------------------------------------------------------------
--                L  O  C  A  L     V  A  R  I  A  B  L  E  S
-------------------------------------------------------------------------------

local addonName, L = ...;

local GUILD_ROSTER_MAX_COLUMNS   = 5;
local GUILD_ROSTER_MAX_STRINGS   = 4;
local GUILD_ROSTER_BAR_MAX       = 239;
local GUILD_ROSTER_BUTTON_OFFSET = 2;
local GUILD_ROSTER_BUTTON_HEIGHT = 20;

local MOBILE_BUSY_ICON = "|TInterface\\ChatFrame\\UI-ChatIcon-ArmoryChat-BusyMobile:14:14:0:0:16:16:0:16:0:16|t";
local MOBILE_AWAY_ICON = "|TInterface\\ChatFrame\\UI-ChatIcon-ArmoryChat-AwayMobile:14:14:0:0:16:16:0:16:0:16|t";

local currentGuildView = view;

local filteredList = {[0] = 0};

local classFlag =
{
  ["DRUID"]       = 0x0001,
  ["DEATHKNIGHT"] = 0x0002,
  ["HUNTER"]      = 0x0004,
  ["MAGE"]        = 0x0008,
  ["MONK"]        = 0x0010,
  ["PALADIN"]     = 0x0020,
  ["PRIEST"]      = 0x0040,
  ["ROGUE"]       = 0x0080,
  ["SHAMAN"]      = 0x0100,
  ["WARLOCK"]     = 0x0200,
  ["WARRIOR"]     = 0x0400
}

local additionalClasses =
{
  {name = L["Any"],     flags = 0xFFFF},
  {name = L["Healing"], flags = 0x0171},
  {name = L["Tanking"], flags = 0x0433}
};

-------------------------------------------------------------------------------
--                L  O  C  A  L     F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
--               G  L  O  B  A  L     V  A  R  I  A  B  L  E  S
-------------------------------------------------------------------------------

NigglesGuildRosterTabOrder =
{
  "NigglesGuildRosterName",
  "NigglesGuildRosterLevelMin",
  "NigglesGuildRosterLevelMax",
  "NigglesGuildRosterZone",
  "NigglesGuildRosterNote"
};

-------------------------------------------------------------------------------
--               G  L  O  B  A  L     F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

--
-- Function for processing clicks on the Niggles guild roster toggle
--
function NigglesGuildRosterButtonOnClick(self, button)
  -- Show/Hide the Niggles Guild Roster
  if (currentGuildView ~= "tradeskill") then
    NigglesGuildRosterShow();
    PlaySound("igMainMenuOptionCheckBoxOn");
  end

  return;
end

--
-- Function to processing the selection of an item in the 'Class' dropdown
--
function NigglesGuildRosterClassOnClick(self, button)
  UIDropDownMenu_SetSelectedValue(NigglesGuildRosterClass, self.value);
  NigglesGuildRosterFilter();
  return;
end

--
-- Function to initialise the 'Class' dropdown
--
function NigglesGuildRosterClassOnLoad(self)
  -- Initialise the dropdown
  UIDropDownMenu_Initialize(self, NigglesGuildRosterClassOnShow);
  UIDropDownMenu_JustifyText(self, "LEFT");
  UIDropDownMenu_SetWidth(self, 100);
  UIDropDownMenu_SetSelectedValue(NigglesGuildRosterClass, 0xFFFF);

  return;
end

--
-- Function called when the 'Class' dropdown is shown.
--
function NigglesGuildRosterClassOnShow()
  -- Local Variables
  local info = UIDropDownMenu_CreateInfo();
  local selected = UIDropDownMenu_GetSelectedValue(NigglesGuildRosterClass);

  -- Initialise the dropdown info
  info.func = NigglesGuildRosterClassOnClick;

  -- Add the additional classes to the dropdown
  for _, classInfo in ipairs(additionalClasses) do
    info.value     = classInfo.flags;
    info.text      = classInfo.name;
    info.checked   = (selected == classInfo.flags);
    UIDropDownMenu_AddButton(info);
  end

  -- Add the classes to the dropdown
  for class, localizedName in pairs(LOCALIZED_CLASS_NAMES_MALE) do
    info.value     = classFlag[class];
    info.text      = localizedName;
    info.checked   = (class == selected);
    info.colorCode = string.format("|cFF%02x%02x%02x",
      (255*RAID_CLASS_COLORS[class].r),
      (255*RAID_CLASS_COLORS[class].g),
      (255*RAID_CLASS_COLORS[class].b));
    UIDropDownMenu_AddButton(info);
  end

  return;
end

--
-- Function to update the Niggles guild roster
--
-- NOTE: This is a modified version of 'GuildRoster_Update()' in
--       'Blizzard_GuildRoster.lua'.
--
function NigglesGuildRosterContainerUpdate()
  -- Modified for Niggles
  local scrollFrame = NigglesGuildRosterContainer;
  local offset = HybridScrollFrame_GetOffset(scrollFrame);
  local buttons = scrollFrame.buttons;
  local numButtons = #buttons;
  local button, index, class;
  local totalMembers, onlineMembers, onlineAndMobileMembers = GetNumGuildMembers();
  local selectedGuildMember = GetGuildRosterSelection();

  if ( currentGuildView == "tradeskill" ) then
    GuildRoster_UpdateTradeSkills();
    return;
  end

  local guildName, guildRankName, guildRankIndex = GetGuildInfo("player");
  local maxRankIndex = GuildControlGetNumRanks() - 1;
  -- Get selected guild member info
  local name, rank, rankIndex, level, class, zone, note, officernote, online, isAway, classFileName, achievementPoints, achievementRank, isMobile = GetGuildRosterInfo(selectedGuildMember);
  GuildFrame.selectedName = name;
  -- If there's a selected guildmember
  if ( selectedGuildMember > 0 ) then
    -- Update the guild member details frame
    if ( isMobile ) then
      if (isAway == 2) then
        GuildMemberDetailName:SetText(MOBILE_BUSY_ICON..GuildFrame.selectedName);
      elseif (isAway == 1) then
        GuildMemberDetailName:SetText(MOBILE_AWAY_ICON..GuildFrame.selectedName);
      else
        GuildMemberDetailName:SetText(ChatFrame_GetMobileEmbeddedTexture(73/255, 177/255, 73/255)..GuildFrame.selectedName);
      end
    else
      GuildMemberDetailName:SetText(GuildFrame.selectedName);
    end
    if ( level and class) then
      GuildMemberDetailLevel:SetFormattedText(FRIENDS_LEVEL_TEMPLATE, level, class);
    else
      GuildMemberDetailLevel:SetText("");
    end
    local zoneText = zone;
    if(isMobile and not online) then zoneText = REMOTE_CHAT; end;
    GuildMemberDetailZoneText:SetText(zoneText);
    GuildMemberDetailRankText:SetText(rank);
    if ( online ) then
      GuildMemberDetailOnlineText:SetText(GUILD_ONLINE_LABEL);
    else
      GuildMemberDetailOnlineText:SetText(GuildRoster_GetLastOnline(selectedGuildMember));
    end
    -- Update public note
    if ( CanEditPublicNote() ) then
      PersonalNoteText:SetTextColor(1.0, 1.0, 1.0);
      if ( (not note) or (note == "") ) then
        note = GUILD_NOTE_EDITLABEL;
      end
    else
      PersonalNoteText:SetTextColor(0.65, 0.65, 0.65);
    end
    GuildMemberNoteBackground:EnableMouse(CanEditPublicNote());
    PersonalNoteText:SetText(note);

    -- Manage guild member related buttons
    -- check if you can promote and the member is at least 2 ranks below you, or if you can demote and the member is not in the last rank, as well as below your rank
    if ( ( CanGuildPromote() and rankIndex > guildRankIndex + 1 ) or ( CanGuildDemote() and rankIndex < maxRankIndex and rankIndex > guildRankIndex ) ) then
      GuildMemberDetailRankLabel:SetHeight(20);
      GuildMemberRankDropdown:Show();
      UIDropDownMenu_SetText(GuildMemberRankDropdown, rank);
    else
      GuildMemberDetailRankLabel:SetHeight(0);
      GuildMemberRankDropdown:Hide();
    end

    -- Update officer note
    if ( CanViewOfficerNote() ) then
      if ( CanEditOfficerNote() ) then
        if ( (not officernote) or (officernote == "") ) then
          officernote = GUILD_OFFICERNOTE_EDITLABEL;
        end
        OfficerNoteText:SetTextColor(1.0, 1.0, 1.0);
      else
        OfficerNoteText:SetTextColor(0.65, 0.65, 0.65);
      end
      GuildMemberOfficerNoteBackground:EnableMouse(CanEditOfficerNote());
      OfficerNoteText:SetText(officernote);

      -- Resize detail frame
      GuildMemberDetailOfficerNoteLabel:Show();
      GuildMemberOfficerNoteBackground:Show();
      GuildMemberDetailFrame:SetHeight(GUILD_DETAIL_OFFICER_HEIGHT + GuildMemberDetailRankLabel:GetHeight());
    else
      GuildMemberDetailOfficerNoteLabel:Hide();
      GuildMemberOfficerNoteBackground:Hide();
      GuildMemberDetailFrame:SetHeight(GUILD_DETAIL_NORM_HEIGHT + GuildMemberDetailRankLabel:GetHeight());
    end

    if ( CanGuildRemove() and ( rankIndex >= 1 ) and ( rankIndex > guildRankIndex ) ) then
      GuildMemberRemoveButton:Enable();
    else
      GuildMemberRemoveButton:Disable();
    end
    if ( (UnitName("player") == name) or (not online) or isMobile ) then
      GuildMemberGroupInviteButton:Disable();
    else
      GuildMemberGroupInviteButton:Enable();
    end

    GuildFrame.selectedName = GetGuildRosterInfo(GetGuildRosterSelection());
  else
    GuildMemberDetailFrame:Hide();
  end

  local maxWeeklyXP, maxTotalXP = GetGuildRosterLargestContribution();
  local maxAchievementsPoints = GetGuildRosterLargestAchievementPoints();
  -- numVisible
  -- Modified for Niggles
  visibleMembers = filteredList[0];

  for i = 1, numButtons do
    button = buttons[i];

    -- Modified for Niggles
    if (offset+i <= visibleMembers) then
      index = filteredList[offset+i];
    else
      index = -1;
    end

    local name, rank, rankIndex, level, class, zone, note, officernote, online, isAway, classFileName, achievementPoints, achievementRank, isMobile, canSoR, repStanding = GetGuildRosterInfo(index);

    local onlineOrMobile = online or isMobile;

    -- Modified for Niggles
    if ((name) and (offset+i <= visibleMembers)) then
      button.guildIndex = index;
      local displayedName = name;
      if ( isMobile ) then
        if (isAway == 2) then
          displayedName = MOBILE_BUSY_ICON..displayedName;
        elseif (isAway == 1) then
          displayedName = MOBILE_AWAY_ICON..displayedName;
        else
          displayedName = ChatFrame_GetMobileEmbeddedTexture(73/255, 177/255, 73/255)..displayedName;
        end
      end
      button.online = onlineOrMobile;
      -- Modified for Niggles
      if ((currentGuildView == "playerStatus") or
          (currentGuildView == nil) or
          (currentGuildView == "")) then
        GuildRosterButton_SetStringText(button.string1, level, onlineOrMobile)
        button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
        GuildRosterButton_SetStringText(button.string2, displayedName, onlineOrMobile, classFileName)
        local zoneText = zone;
        if(isMobile and not online) then zoneText = REMOTE_CHAT; end;
        GuildRosterButton_SetStringText(button.string3, zoneText, onlineOrMobile)
      elseif ( currentGuildView == "guildStatus" ) then
        GuildRosterButton_SetStringText(button.string1, displayedName, onlineOrMobile, classFileName)
        GuildRosterButton_SetStringText(button.string2, rank, onlineOrMobile)
        GuildRosterButton_SetStringText(button.string3, note, onlineOrMobile)

        if ( onlineOrMobile ) then
          GuildRosterButton_SetStringText(button.string4, GUILD_ONLINE_LABEL, onlineOrMobile);
        else
          GuildRosterButton_SetStringText(button.string4, GuildRoster_GetLastOnline(index), onlineOrMobile);
        end
      elseif ( currentGuildView == "weeklyxp" ) then
        local weeklyXP, totalXP, weeklyRank, totalRank = GetGuildRosterContribution(index);
        GuildRosterButton_SetStringText(button.string1, level, onlineOrMobile)
        button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
        GuildRosterButton_SetStringText(button.string2, displayedName, onlineOrMobile, classFileName)
        GuildRosterButton_SetStringText(button.string3, weeklyXP, onlineOrMobile)
        if ( weeklyXP == 0 ) then
          button.barTexture:Hide();
        else
          button.barTexture:SetWidth(weeklyXP / maxWeeklyXP * GUILD_ROSTER_BAR_MAX);
          button.barTexture:Show();
        end
        GuildRosterButton_SetStringText(button.barLabel, "#"..weeklyRank, onlineOrMobile);
      elseif ( currentGuildView == "totalxp" ) then
        local weeklyXP, totalXP, weeklyRank, totalRank = GetGuildRosterContribution(index);
        GuildRosterButton_SetStringText(button.string1, level, onlineOrMobile);
        button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
        GuildRosterButton_SetStringText(button.string2, displayedName, onlineOrMobile, classFileName);
        GuildRosterButton_SetStringText(button.string3, totalXP, onlineOrMobile);
        if ( totalXP == 0 ) then
          button.barTexture:Hide();
        else
          button.barTexture:SetWidth(totalXP / maxTotalXP * GUILD_ROSTER_BAR_MAX);
          button.barTexture:Show();
        end
        GuildRosterButton_SetStringText(button.barLabel, "#"..totalRank, onlineOrMobile);
      elseif ( currentGuildView == "pve" ) then
        GuildRosterButton_SetStringText(button.string1, level, onlineOrMobile);
        button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
        GuildRosterButton_SetStringText(button.string2, displayedName, onlineOrMobile, classFileName);
        GuildRosterButton_SetStringText(button.string3, valor, onlineOrMobile);
        GuildRosterButton_SetStringText(button.string4, hero, onlineOrMobile);
      elseif ( currentGuildView == "pvp" ) then
        local bgRating, arenaRating, arenaTeam = GetGuildRosterPVPRatings(index);
        GuildRosterButton_SetStringText(button.string1, level, onlineOrMobile);
        button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
        GuildRosterButton_SetStringText(button.string2, displayedName, onlineOrMobile, classFileName);
        GuildRosterButton_SetStringText(button.string3, bgRating, onlineOrMobile);
        GuildRosterButton_SetStringText(button.string4, string.format(GUILD_ROSTER_ARENA_RATING, arenaRating, arenaTeam, arenaTeam), onlineOrMobile);
      elseif ( currentGuildView == "achievement" ) then
        GuildRosterButton_SetStringText(button.string1, level, onlineOrMobile);
        button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
        GuildRosterButton_SetStringText(button.string2, displayedName, onlineOrMobile, classFileName);
        if ( achievementPoints >= 0 ) then
          GuildRosterButton_SetStringText(button.string3, achievementPoints, onlineOrMobile);
          if ( achievementPoints == 0 ) then
            button.barTexture:Hide();
          else
            button.barTexture:SetWidth(achievementPoints / maxAchievementsPoints * GUILD_ROSTER_BAR_MAX);
            button.barTexture:Show();
          end
        else
          GuildRosterButton_SetStringText(button.string3, NO_ROSTER_ACHIEVEMENT_POINTS, onlineOrMobile);
          button.barTexture:Hide();
        end
        GuildRosterButton_SetStringText(button.barLabel, "#"..achievementRank, onlineOrMobile);
      elseif ( currentGuildView == "reputation" ) then
        GuildRosterButton_SetStringText(button.string1, level, onlineOrMobile)
        button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
        GuildRosterButton_SetStringText(button.string2, displayedName, onlineOrMobile, classFileName);
        GuildRosterButton_SetStringText(button.string3, GetText("FACTION_STANDING_LABEL"..repStanding, gender), onlineOrMobile);
      end
      button:Show();

      -- Modified for Niggles
      if ( mod(offset+i, 2) == 0 ) then
        button.stripe:SetTexCoord(0.36230469, 0.38183594, 0.95898438, 0.99804688);
      else
        button.stripe:SetTexCoord(0.51660156, 0.53613281, 0.88281250, 0.92187500);
      end
      if ( selectedGuildMember == index ) then
        button:LockHighlight();
      else
        button:UnlockHighlight();
      end
    else
      button:Hide();
    end
  end
  local totalHeight = visibleMembers * (GUILD_ROSTER_BUTTON_HEIGHT + GUILD_ROSTER_BUTTON_OFFSET);
  local displayedHeight = numButtons * (GUILD_ROSTER_BUTTON_HEIGHT + GUILD_ROSTER_BUTTON_OFFSET);
  HybridScrollFrame_Update(scrollFrame, totalHeight, displayedHeight);
end

--
-- Function to filter the Niggles guild roster
--
function NigglesGuildRosterFilter()
  -- Local Variables
  local visibleMembers;
  local name;
  local rankIdx;
  local level;
  local class;
  local zone;
  local note;
  local classFileName;
  local filterValues = {};
  local numMatches = 0;

  -- Work out how many guild members should be visible in the roster
  if (GetGuildRosterShowOffline()) then
    visibleMembers, _ = GetNumGuildMembers();
  else
    _, _, visibleMembers = GetNumGuildMembers();
  end

  -- Get the drop down filters
  filterValues.class =
    UIDropDownMenu_GetSelectedValue(NigglesGuildRosterClass);
  filterValues.rank  =
    (tonumber(UIDropDownMenu_GetSelectedValue(NigglesGuildRosterRank)) or 0)-1;

  -- Get some of the edit box filters
  filterValues.name = NigglesGuildRosterName:GetText():lower();
  filterValues.zone = NigglesGuildRosterZone:GetText():lower();
  filterValues.note = NigglesGuildRosterNote:GetText():lower();

  -- Get the level range
  filterValues.levelMin = (tonumber(NigglesGuildRosterLevelMin:GetText()) or 0);
  filterValues.levelMax = (tonumber(NigglesGuildRosterLevelMax:GetText()) or 0);
  if (filterValues.levelMin > 0) and (filterValues.levelMax == 0) then
    filterValues.levelMax = filterValues.levelMin;
  elseif (filterValues.levelMin == 0) and (filterValues.levelMax > 0) then
    filterValues.levelMin = filterValues.levelMax;
  elseif (filterValues.levelMin > filterValues.levelMax) then
    filterValues.levelMin, filterValues.levelMax =
      filterValues.levelMax, filterValues.levelMin;
  end

  -- Filter the guild members
  for idx = 1, visibleMembers do
    -- Get the required info for the member
    name, _, rankIdx, level, _, zone, note, _, _, _, classFileName =
      GetGuildRosterInfo(idx);

    -- Check if the member matches the filter
    if (((filterValues.name == nil) or
         ((name or ""):lower():find(filterValues.name, 1, true) ~= nil)) and
        (bit.band(filterValues.class, classFlag[classFileName]) ~= 0) and
        ((filterValues.levelMin == 0) or
        ((level >= filterValues.levelMin) and
         (level <= filterValues.levelMax))) and
        ((filterValues.rank < 0) or
         (rankIdx == filterValues.rank)) and
        ((filterValues.zone == nil) or
         ((zone or ""):lower():find(filterValues.zone) ~= nil)) and
        ((filterValues.note == nil) or
         ((note or ""):lower():find(filterValues.note) ~= nil))) then
      numMatches = numMatches+1;
      filteredList[numMatches] = idx;
    end
  end
  filteredList[0] = numMatches;

  -- Update the Niggles Guild roster
  NigglesGuildRosterContainerUpdate();

  return;
end

--
-- Function to initialise the Niggles Guild Roster
--
function NigglesGuildRosterInit()
  -- Local Variables
  local button;

  -- Hook into functions that change the view
  hooksecurefunc("GuildRoster_SetView", NigglesGuildRosterSetView);

  -- Create the button for toggling the Niggles guild roster
  button = CreateFrame("BUTTON", "NigglesGuildRosterButton", GuildRosterFrame,
    "NigglesGuildRosterButtonTemplate");
  button.icon:SetTexture("Interface\\Common\\UI-Searchbox-Icon");
  button.icon:SetTexCoord(0, 1, 0, 1);
  if (NigglesDBC.settings.UiGuildRosterFilter == true) then
    button:Show();
    NigglesGuildRosterSetView(GetCVar("guildRosterView"));
  else
    button:Hide();
  end

  return;
end

--
-- Function to processing the selection of an item in the 'Rank' dropdown
--
function NigglesGuildRosterRankOnClick(self, button)
  UIDropDownMenu_SetSelectedValue(NigglesGuildRosterRank, self.value);
  NigglesGuildRosterFilter();
  return;
end

function NigglesGuildRosterRankOnLoad(self)
  -- Initialise the dropdown
  UIDropDownMenu_Initialize(self, NigglesGuildRosterRankOnShow);
  UIDropDownMenu_JustifyText(self, "LEFT");
  UIDropDownMenu_SetWidth(self, 100);
  UIDropDownMenu_SetSelectedValue(NigglesGuildRosterRank, 0);

  return;
end

--
-- Function called when the 'Rank' dropdown is shown.
--
function NigglesGuildRosterRankOnShow()
  -- Local Variables
  local info = UIDropDownMenu_CreateInfo();
  local numRanks = GuildControlGetNumRanks();
  local selected = UIDropDownMenu_GetSelectedValue(NigglesGuildRosterRank);

  -- Initialise the dropdown info
  info.func = NigglesGuildRosterRankOnClick;

  -- Add 'Any' to the dropdown
  info.text    = L["Any"];
  info.value   = 0;
  info.checked = (idx == selected);
  UIDropDownMenu_AddButton(info);

  -- Add the guild's ranks to the dropdown
  for idx = 1, numRanks do
    info.text    = GuildControlGetRankName(idx);
    info.value   = idx;
    info.checked = (idx == selected);
    UIDropDownMenu_AddButton(info);
  end

  return;
end

--
-- Function called when the user selects a different guild roster view
--
function NigglesGuildRosterSetView(view)
  -- Local Variables
  local button;
  local numButtons;
  local buttonFontString;
  local stdButton = GuildRosterContainer.buttons[1];
  local fontString;
  local stringInfo = {};
  local numPoints;
  local xOffset;
  local haveIcon = stdButton.icon:IsShown();
  local haveBar  = stdButton.barLabel:IsShown();

  -- Save the new view
  currentGuildView = view;

  -- Check if the new view is 'tradeskill'
  if (view == "tradeskill") then
    -- Hide the Niggles guild roster...
    NigglesGuildRosterShow(false);

    -- Disable the button for toggling the Niggles guild roster
    NigglesGuildRosterButton:Disable();
  else
    -- Check the Niggles Guild roster exists
    if (NigglesGuildRosterContainer ~= nil) then
      -- Get info about the first standard guild roster buttons
      for idx = 1, GUILD_ROSTER_MAX_STRINGS do
        -- Check if the font string is shown
        fontString = stdButton["string"..idx];
        if (fontString:IsShown()) then
          -- Get the font string's width and horizontal justification
          stringInfo[idx] =
          {
            width    = fontString:GetWidth(),
            justifyH = fontString:GetJustifyH(),
          }

          -- Find the X offset for the font string's left point
          numPoints = fontString:GetNumPoints();
          for pointIdx = 1, numPoints do
            point, _, _, xOffset, _ = fontString:GetPoint(pointIdx);
            if (point == "LEFT") then
              stringInfo[idx].leftOffset = xOffset;
              break;
            end
          end
        end
      end

      -- Adjust the Niggles guild roster buttons for the new view
      numButtons = #NigglesGuildRosterContainer.buttons;
      for idx = 1, numButtons do
        button = NigglesGuildRosterContainer.buttons[idx];
        for stringIdx = 1, GUILD_ROSTER_MAX_STRINGS do
          fontString = button["string"..stringIdx];
          if (stringInfo[stringIdx] ~= nil) then
            fontString:SetPoint("LEFT", stringInfo[stringIdx].leftOffset, 0);
            fontString:SetWidth(stringInfo[stringIdx].width);
            fontString:SetJustifyH(stringInfo[stringIdx].justifyH);
            fontString:Show();
          else
            fontString:Hide();
          end
        end

        -- Show/Hide the button icon and bar
        button.icon:SetShown(haveIcon);
        if (haveBar) then
          button.barLabel:Show();
          -- NOTE: The texture is shown in 'NigglesGuildRosterContainerUpdate()'
        else
          button.barLabel:Hide();
          button.barTexture:Hide();
        end
        button.header:Hide();
      end

      -- Update the Niggles guild roster, if required
      if (NigglesGuildRosterContainer:IsShown()) then
        NigglesGuildRosterContainerUpdate();
      end
    end

    -- Make sure the button for toggling the Niggles guild roster is enabled
    NigglesGuildRosterButton:Enable();
  end

  return;
end

--
-- Function to show/hide the Niggles guild roster, with its additional filters
--
function NigglesGuildRosterShow(show)
  -- Clear any selection
  SetGuildRosterSelection(0);
  GuildFrame.selectedGuildMember = 0;
  GuildMemberDetailFrame:Hide();

  -- Work out if the Niggles guild roster should be shown
  if (show == nil) then
    if (NigglesGuildRoster == nil) then
      show = true;
    else
      show = not NigglesGuildRoster:IsShown();
    end
  end

  -- Create the Niggles guild roster, if required
  if ((NigglesGuildRosterContainer == nil) and (show)) then
    -- Create the Niggles guild roster
    CreateFrame("FRAME", "NigglesGuildRoster", GuildRosterFrame,
      "NigglesGuildRosterTemplate");

    -- Initialise the Niggles guild roster scroll frame
    NigglesGuildRosterContainer.update = NigglesGuildRosterContainerUpdate;
    HybridScrollFrame_CreateButtons(NigglesGuildRosterContainer,
      "GuildRosterButtonTemplate", 0, 0, "TOPLEFT", "TOPLEFT", 0,
      -GUILD_ROSTER_BUTTON_OFFSET, "TOP", "BOTTOM");
    NigglesGuildRosterContainerScrollBar.doNotHide = true;

    -- Adjust the standard column headers
    for idx = 1, GUILD_ROSTER_MAX_COLUMNS do
      -- Adjust the frame level of the column headers
      button = _G["GuildRosterColumnButton"..idx];
      button:SetFrameLevel(button:GetFrameLevel()+1);

      -- Hook into the 'OnClick' event
      button:HookScript("OnClick", NigglesGuildRosterContainerUpdate);
    end

    -- Hook into frames that change the view
    GuildRosterShowOfflineButton:HookScript("OnClick",
      NigglesGuildRosterFilter);
    for idx = 1, #(NigglesGuildRosterContainer.buttons) do
      NigglesGuildRosterContainer.buttons[idx]:HookScript("OnClick",
        NigglesGuildRosterContainerUpdate);
    end

    -- Initialise the view of the Niggles guild roster
    NigglesGuildRosterSetView(GetCVar("guildRosterView"));
  end

  -- Show/Hide the Niggles guild roster
  if (show) then
    -- Set all the filters to their default values
    NigglesGuildRosterName:SetText("");
    UIDropDownMenu_Initialize(NigglesGuildRosterClass,
      NigglesGuildRosterClassOnShow);
    UIDropDownMenu_SetSelectedValue(NigglesGuildRosterClass, 0xFFFF);
    NigglesGuildRosterZone:SetText("");
    NigglesGuildRosterLevelMin:SetText("");
    NigglesGuildRosterLevelMax:SetText("");
    UIDropDownMenu_Initialize(NigglesGuildRosterRank,
      NigglesGuildRosterRankOnShow);
    UIDropDownMenu_SetSelectedValue(NigglesGuildRosterRank, 0);
    NigglesGuildRosterNote:SetText("");

    -- Initialise the filtered list
    NigglesGuildRosterFilter();

    -- Show the Niggles guild roster
    NigglesGuildRoster:Show();

    -- Hide the standard guild roster
    GuildRosterContainer:Hide();

    -- Move the column buttons to the top of the Niggles guild roster
    GuildRosterColumnButton1:ClearAllPoints();
    GuildRosterColumnButton1:SetPoint("TOPLEFT", GuildRosterFrame,
      "TOPLEFT", 7, -150);
  else
    -- Hide the Niggles Guild Roster
    if (NigglesGuildRosterContainer ~= nil) then
      NigglesGuildRoster:Hide();
    end

    -- Show the standard guild roster
    GuildRosterContainer:Show();

    -- Move the column buttons to the top of the standard guild roster
    GuildRosterColumnButton1:ClearAllPoints();
    GuildRosterColumnButton1:SetPoint("TOPLEFT", GuildRosterFrame,
      "TOPLEFT", 7, -68);

    -- Force the standard guild roster to update
    GuildRoster_Update();
  end

  return;
end
