-------------------------------------------------------------------------------
--                L  O  C  A  L     V  A  R  I  A  B  L  E  S
-------------------------------------------------------------------------------

local addonName, L = ...;

-------------------------------------------------------------------------------
--                L  O  C  A  L     F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
--               G  L  O  B  A  L     F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

--
-- Function to enable/disable Merchant Search
--
function NigglesMerchantSearchEnable()
  -- Local Variables
  local button;
  local frame;
  local texture;

  -- Check if the edit box and textures need to be created
  if ((NigglesMerchantSearch == nil) and
      (NigglesDBC.settings.UiMerchantSearch)) then
    -- Create the edit box
    CreateFrame("EDITBOX", "NigglesMerchantSearch", MerchantFrame,
      "NigglesMerchantSearchTemplate");

    -- Create the textures
    for buttonIdx = 1, MERCHANT_ITEMS_PER_PAGE do
      texture = _G["MerchantItem"..buttonIdx.."ItemButton"]:CreateTexture(
        "NigglesMerchantItemButton"..buttonIdx, "OVERLAY");
      texture:SetAllPoints();
      texture:SetTexture(0, 0, 0, 0.8);
      frame = CreateFrame("Frame", "NigglesMerchantItemLabel"..buttonIdx,
        _G["MerchantItem"..buttonIdx]);
      frame:SetFrameLevel(129);
      frame:SetPoint("TOPLEFT", _G["MerchantItem"..buttonIdx.."NameFrame"],
        1, -3);
      frame:SetWidth(104);
      frame:SetHeight(45);
      texture = frame:CreateTexture(nil, "OVERLAY");
      texture:SetAllPoints();
      texture:SetTexture(0, 0, 0, 0.8);
    end
  end

  -- Check if Merchant Search is enabled
  if (NigglesDBC.settings.UiMerchantSearch) then
    -- Show the Merchant Search edit box
    NigglesMerchantSearch:Show();

    -- Update the Merchant's frame, if shown
    if (MerchantFrame:IsShown()) then
      MerchantFrame_Update();
    end
  else
    -- Hide the Merchant Search edit box, if required
    if (NigglesMerchantSearch ~= nil) then
      NigglesMerchantSearch:Hide();
    end
  end

  return;
end

--
-- Function used to update the Merchant frame, based on the search text
--
function NigglesMerchantSearchUpdate()
  -- Local Variables
  local itemIdx;
  local itemMatch;
  local itemOffset = ((MerchantFrame.page-1)*MERCHANT_ITEMS_PER_PAGE);
  local searchText;
  local numItems = GetMerchantNumItems();
  local numCurrencies;
  local currencyLink;

  -- Check if searching is enabled
  if (NigglesDBC.settings.UiMerchantSearch) then
    -- Get the search text
    searchText = NigglesMerchantSearch:GetText();
    if ((searchText == SEARCH) or (searchText == nil)) then
      searchText = "";
    else
      searchText = string.lower(searchText);
    end

    -- Set the vertex colour, depending on the buttons' text
    for buttonIdx = 1, MERCHANT_ITEMS_PER_PAGE do
      -- Initialise some variables
      itemIdx       = itemOffset+buttonIdx;
      itemMatch     = true;
      numCurrencies = GetMerchantItemCostInfo(itemIdx);

      -- Check if the name of the button's item matches the search string
      if ((searchText ~= "") and (itemIdx <= numItems)) then
        if (string.find(string.lower(GetMerchantItemInfo(itemIdx) or ""),
             searchText, 1, true) == nil) then
          itemMatch = false;
        end

        -- If the item's name doesn't match
        if ((not itemMatch) and (numCurrencies > 0)) then
          -- Check if any alternative currency item matches the search string
          for currencyIdx = 1, numCurrencies do
            _, _, currencyLink = GetMerchantItemCostItem(itemIdx,
              currencyIdx);
            if ((currencyLink ~= nil) and
                (string.find(string.lower(string.match(currencyLink,
                  "|h%[(.*)%]|h|r") or ""), searchText, 1, true) ~= nil)) then
              itemMatch = true;
              break;
            end
          end
        end
      end

      -- Show/Hide the merchant item's textures
      _G["NigglesMerchantItemButton"..buttonIdx]:SetShown(not itemMatch);
      _G["NigglesMerchantItemLabel"..buttonIdx]:SetShown(not itemMatch);
    end

    -- Show/Hide the Clear button
    NigglesMerchantSearch.clearButton:SetShown(searchText ~= "");
  end

  return;
end
